@@ -25,8 +25,6 @@ class Q_DECL_HIDDEN FilterInfo::Private
 {
 public:
     Private()
-        : m_removeDupMsg(false)
-        , m_filterInfoGui(nullptr)
     {
     }
 
@@ -36,8 +34,8 @@ public:
         m_filterInfoGui = nullptr;
     }
 
-    bool m_removeDupMsg;
-    FilterInfoGui *m_filterInfoGui;
+    bool m_removeDupMsg = false;
+    FilterInfoGui *m_filterInfoGui = nullptr;
     static bool s_terminateASAP;
 };
 
