@@ -25,6 +25,8 @@ namespace MailImporter {
 namespace OtherMailerUtil {
 MAILIMPORTER_EXPORT QString trojitaDefaultPath();
 MAILIMPORTER_EXPORT QString gearyDefaultPath();
+MAILIMPORTER_EXPORT QStringList isMailerFound();
+MAILIMPORTER_EXPORT QString nylasMailDefaultPath();
 }
 }
 
